ABlog v0.10 released
====================

.. post:: Nov 17, 2019
   :author: Nabil
   :category: Release
   :location: World


ABlog v0.10 is released with the main focus being to support the latest version of Sphinx as well as Python 3 only support.

Ablog V0.9.X will no longer be supported as Python 2 comes to an end in a few months and it is time people upgraded.

Pull Requests Merged in:

`Overhaul of package underneath for python3 only <https://github.com/sunpy/ablog/pull/41>`_
from `nabobalis <https://github.com/nabobalis>`_.

`Add validation for conf.py entries <https://github.com/sunpy/ablog/pull/38>`_ from `rayalan <https://github.com/rayalan>`_.

`Deploy improve <https://github.com/sunpy/ablog/pull/42>`_ from `rayalan <https://github.com/rayalan>`_.

`Get ablog ready for 0.10 <https://github.com/sunpy/ablog/pull/46>`_ from `nabobalis <https://github.com/nabobalis>`_.
